@@ -4,7 +4,7 @@ use strict;
 package Jifty::DBI::Filter;
 use base 'Class::Accessor::Fast';
 
-__PACKAGE__->mk_accessors(qw(record column value_ref));
+__PACKAGE__->mk_accessors(qw(record column value_ref handle));
 
 =head1 NAME
 
@@ -52,7 +52,7 @@ A filter allows Jifty::DBI models to tweak data prior to being stored and/or loa
 
 =head2 new
 
-Takes two arguments in a parameter hash:
+Takes three arguments in a parameter hash:
 
 =over
 
@@ -67,6 +67,11 @@ refers to.
 A L<Jifty::DBI::Column> object, whatever sort of column we're working
 with here.
 
+=item handle
+
+A L<Jifty::DBI::Handle> object, because some filters (ie
+L<Jifty::DBI::Filter::Boolean>) depend on what database system is being used.
+
 =back
 
 =cut
@@ -76,20 +81,21 @@ sub new {
     my %args  = (
         column    => undef,
         value_ref => undef,
+        handle    => undef,
         @_
     );
-    my $self = {};
-    bless $self, $class;
-
-    for ( keys %args ) {
-        if ( $self->can($_) ) {
-            $self->$_( $args{$_} );
-        }
-
+    my $self = $class->SUPER::new( {
+        record    => delete $args{record},
+        column    => delete $args{column},
+        value_ref => delete $args{value_ref},
+        handle    => delete $args{handle},
+    } );
+    
+    for ( grep $self->can($_), keys %args ) {
+        $self->$_( $args{$_} );
     }
 
     return ($self);
-
 }
 
 =head2 encode
